"""pyffstream.

Script and tools to enable streaming files or OBS with ffmpeg to a
remote server. Specializes in sending over SRT.
"""
# from ._globals import FFBin
# from . import globals_
# from . import stream
